package src.com.galya;

import src.com.goldencode.p2j.util.logging.*;

import java.io.*;
import java.util.*;
import java.util.logging.*;

public class LoggingTest
{
   
   public static void main(String[] args)
   throws IOException
   {
      // 2174ms - 3424ms, redirected 4573ms
      // one of the traditional FWD ways of logging
      // systemErr();
      
      // 32912ms, redirected 21647ms, 21600ms
      // one of the traditional FWD ways of logging
      // javaLoggerSystemErr();
      
      // 9235ms, 9062ms, 9523ms
      // never used in FWD
      // javaLoggerFileSystem();
      
      // 13911ms, 13560ms
      // the new way
      // centralLogger();
   }

   public static void centralLogger()
   throws IOException
   {
      CentralLogger.setMode(CentralLogger.Mode.SERVER);
      CentralLoggerServer.initialize(new CentralLoggerServer.ConfigsBuilder().filePath("centralLogger.log").build());
      CentralLogger logger = CentralLogger.get("com.galya");
      long start = new Date().getTime();
      for (int i = 0; i < 1000000; i++)
      {
         logger.warning("bla");
      }
      long end = new Date().getTime();

      long interval = end - start;
      System.out.println("centralLogger interval " + interval);
   }

   public static void systemErr()
   {
      long start = new Date().getTime();
      for (int i = 0; i < 1000000; i++)
      {
         System.err.println("bla");
      }
      long end = new Date().getTime();

      long interval = end - start;
      System.out.println("systemErr interval " + interval);
   }

   public static void javaLoggerSystemErr()
   throws IOException
   {
      Logger rootLogger = Logger.getLogger("");
      rootLogger.addHandler(new ConsoleHandler());
      
      Logger anotherLogger = Logger.getLogger("com.galya");
      long start = new Date().getTime();
      for (int i = 0; i < 1000000; i++)
      {
         anotherLogger.warning("bla");
      }
      long end = new Date().getTime();

      long interval = end - start;
      System.out.println("javaLoggerSystemErr interval " + interval);
   }
   
   public static void javaLoggerFileSystem()
   throws IOException
   {
      Logger rootLogger = Logger.getLogger("");
      FileHandler fileHandler = new FileHandler("test.log");
      Handler[] handlers = rootLogger.getHandlers();
      for (Handler defaultHandler : handlers)
      {
         rootLogger.removeHandler(defaultHandler);
      }
      rootLogger.addHandler(fileHandler);

      Logger anotherLogger = Logger.getLogger("com.galya");
      long start = new Date().getTime();
      for (int i = 0; i < 1000000; i++)
      {
         anotherLogger.warning("bla");
      }
      fileHandler.flush();
      fileHandler.close(); 
      long end = new Date().getTime();

      long interval = end - start;
      System.out.println("javaLoggerFileSystem interval " + interval);
   }
   
   
}
